[![pipeline status](https://gitlab.com/nicolalandro/streamlit-seqviz/badges/main/pipeline.svg)](https://gitlab.com/nicolalandro/streamlit-seqviz/-/commits/main) 

[![License: MIT](https://img.shields.io/badge/license-MIT-lightgray)](LICENSE) 

[![Open in Streamlit](https://huggingface.co/datasets/huggingface/badges/raw/refs%2Fpr%2F11/open-in-hf-spaces-md-dark.svg)](https://huggingface.co/spaces/z-uo/DNASequenceVisualization)

# Streamlit SeqViz
A Streamlit library for [seqviz](https://www.npmjs.com/package/seqviz)

|white theme | dark theme |
|------------|------------|
|![Streamlit sample white theme](imgs/white_screen.png)|![Streamlit sample dark theme](imgs/black_screen.png)|


Install from pypi with:

```
pip install streamlit-seqviz
```

You can install it from gitlab repository with:

```
pip install streamlit-seqviz --index-url https://gitlab.com/api/v4/projects/46186878/packages/pypi/simple
```

And you can use it:

```
from streamlit_seqviz import streamlit_seqviz

streamlit_seqviz(
    name = "J23100",
    seq = "TTGACGGCTAGCTCAGTCCTAGGTACAGTGCTAGC",
    annotations = [{ "name": "promoter", "start": 0, "end": 30, "direction": 1 }],
    style =  { "height": "100vh", "width": "100vw" },
    highlights = [{ "start": 0, "end": 10 }],
    enzymes = [
        "EcoRI",
        "PstI",
        {
            "name": "Cas9",
            "rseq": "NGG", # recognition sequence
            "fcut": 0, # cut index on FWD strand, relative to start of rseq
            "rcut": 1, # cut index on REV strand, relative to start of rseq
            "color": "#D7E5F0", # color to highlight recognition site with
            "range": {
                "start": 4,
                "end": 8,
            },
        },
    ],
)
```


## Roaadmap

* [x] show component
* [x] support params name, seq, annotations,style, highlights, enzymes
* [ ] deploy on pypi (Pypi Project registration temporary suspended see [here](https://status.python.org/incidents/qy2t9mjjcc7g))
* [ ] add an opensource Licence
* [ ] support the rest of parameters
* [ ] on selection return values on streamlit
* [ ] adaptive size
* [ ] automation test

## Develop
This is the guide for developers.

### Frontend
```
cd streamlit_seqviz/frontend
npm install

npm run dev
# http://localhost:5173/
```

### Streamlit
```
python3 -m venv venv
source venv/bin/activate.fish
pip install streamlit

streamlit run streamlit_seqviz/__init__.py
# http://localhost:8501/
```

## Tesing builded lib
```
python3 -m venv venv
# Set from streamlit_seqviz/__init__.py _RELEASE=True
pip install -e .
streamlit run test.py
```

## Deploy pipy
```
keyring set https://upload.pypi.org/legacy/ <pypi uname>
```

* prepare your ~/.pypirc file

```
[pypi]
repository=https://upload.pypi.org/legacy/
username = __token__
password = <token>
```

* build frontend

```
cd streamlit_seqviz/frontend
rm -rf dist
npm run build
```

* build backend

```
pip install twine

# Set from streamlit_seqviz/__init__.py _RELEASE=True
rm -rf dist

python setup.py sdist
twine check dist/*
```

* upload

```
twine upload dist/*
```

## References
* [python](https://www.python.org/): programming language for develop the tool
* [HTML](https://www.w3schools.com/html/): markup language for the output file generated by the tool
* [JavaScript](https://www.w3schools.com/js/): programming language used into the HTML for logic implementation 
* [vite](https://vitejs.dev/): js builder
* [streamlit](https://streamlit.io/): python library to make quick and dirty UI
* [vite vanilla js streamlit component](https://dev.to/aisone/streamlit-custom-components-vite-vanilla-js-40hl): how to create vanilla js plugin for streamlit
* [How to use seq-viz](https://medium.com/lattice-automation/visualize-your-dna-sequences-with-seqviz-b1d945eb9684): a library for draw dna sequences
* [How to write setup.py and deploy on pypi](https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56): important for deploy the code as python lib
* [Gitlab CI/CD for python registry](https://docs.gitlab.com/ee/user/packages/pypi_repository/): how to setup pipeline to gitlab python registry
